DartBlockExecutionResult class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

DartBlockExecutionResult({required List<String> consoleOutput, required Map<String, dynamic> environment, required int currentStatementBlockKey, required Map<String, dynamic>? currentStatement, required List<int> blockHistory, required Map<String, dynamic>? exception})
DartBlockExecutionResult.fromJson(Map<String, dynamic> json)
factory

Properties

blockHistory → List<int>
final
consoleOutput → List<String>
final
currentStatement → Map<String, dynamic>?
final
currentStatementBlockKey → int
final
environment → Map<String, dynamic>
final
exception ↔ Map<String, dynamic>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCurrentStatement() → Statement?
getEnvironment() → DartBlockEnvironment?
getException() → DartBlockException?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited