DartBlockNativeMaterialTheme class

Constructors

DartBlockNativeMaterialTheme(TextTheme textTheme)
const

Properties

extendedColors List<ExtendedColor>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textTheme → TextTheme
final

Methods

dark() → ThemeData
darkHighContrast() → ThemeData
darkMediumContrast() → ThemeData
light() → ThemeData
lightHighContrast() → ThemeData
lightMediumContrast() → ThemeData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
theme(ColorScheme colorScheme) → ThemeData
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

darkHighContrastScheme() → ColorScheme
darkMediumContrastScheme() → ColorScheme
darkScheme() → ColorScheme
lightHighContrastScheme() → ColorScheme
lightMediumContrastScheme() → ColorScheme
lightScheme() → ColorScheme

Constants

boolean → const ExtendedColor
Boolean
function → const ExtendedColor
Function
number → const ExtendedColor
Number
string → const ExtendedColor
String
variable → const ExtendedColor
Variable