DartBlockBooleanOperator enum

Inheritance
Available extensions
Annotations
  • @JsonEnum.new()

Values

and → const DartBlockBooleanOperator
const DartBlockBooleanOperator('and', "&&")
or → const DartBlockBooleanOperator
const DartBlockBooleanOperator('or', "||")

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
jsonValue → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
final

Methods

describeVerbal() → String
Describe the operator in spoken English (short).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toScript({DartBlockTypedLanguage language = DartBlockTypedLanguage.java}) → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<DartBlockBooleanOperator>
A constant List of the values in this enum, in order of their declaration.