DartBlockValueTreeBooleanGenericConcatenationNode class

Inheritance
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

hashCode → int
The hash code for this object.
no setterinherited
logicalGenericNodeType → DartBlockValueTreeBooleanGenericNodeType
finalinherited
logicalNodeType → DartBlockValueTreeBooleanNodeType
finalinherited
nodeKey ↔ String
getter/setter pairinherited
nodeType → DartBlockValueTreeNodeType
finalinherited
parent ↔ DartBlockValueTreeBooleanNode?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ DartBlockConcatenationValue
getter/setter pairinherited

Methods

backspace() → DartBlockValueTreeBooleanNode?
Receive a delete (backspace) request, which should delete the right-most component (constant, dynamic value, etc.).
inherited
copy() → DartBlockValueTreeBooleanGenericConcatenationNode
Return a deep copy of the node.
override
deleteRightLeaf() → DartBlockValueTreeBooleanNode?
inherited
findNodeByKey(String key) → DartBlockValueTreeBooleanNode?
Must be overriden by composed types. (See example implementation: ValueCompositionLogicalOperatorNode)
inherited
getRightLeaf() → DartBlockValueTreeBooleanNode
inherited
getRoot() → DartBlockValueTreeBooleanNode
Traverse the tree upwards and retrieve the root. The root is defined as the node which has no parent.
inherited
getValue(DartBlockArbiter arbiter) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
receiveConstant(bool constant) → DartBlockValueTreeBooleanNode
inherited
receiveDynamicValue(DartBlockDynamicValue dynamicValue) → DartBlockValueTreeBooleanNode
inherited
receiveEqualityOperator(DartBlockEqualityOperator operator) → DartBlockValueTreeBooleanNode
inherited
receiveLogicalOperator(DartBlockBooleanOperator operator) → DartBlockValueTreeBooleanNode
inherited
receiveNumberComparisonOperator(DartBlockNumberComparisonOperator operator) → DartBlockValueTreeBooleanNode
inherited
receiveNumberComposedValue(DartBlockAlgebraicExpression numberComposedValue) → DartBlockValueTreeBooleanNode
inherited
receiveValueConcatenation(DartBlockConcatenationValue valueConcatenation) → DartBlockValueTreeBooleanNode
inherited
replaceChild(covariant DartBlockValueTreeNode oldChild, covariant DartBlockValueTreeNode? newChild) → DartBlockValueTreeBooleanNode?
inherited
toJson() → Map<String, dynamic>
override
toScript({DartBlockTypedLanguage language = DartBlockTypedLanguage.java}) → String
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited