EvaluatorSchemaSerializationException class

An exception thrown when the JSON decoding via DartBlockEvaluationSchema.fromJson fails. This is not a DartBlockException thrown during a program's execution or shown to the user.

Implemented types

Constructors

EvaluatorSchemaSerializationException(String? evaluatorSchemaField)

Properties

evaluatorSchemaField → String?
The type of the DartBlockEvaluationSchema being decoded, based on the JSON key 'schemaType'.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited