BreakStatement class

Inheritance
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

BreakStatement(StatementType statementType, String statementId)
BreakStatement.fromJson(Map<String, dynamic> json)
factory
BreakStatement.init()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statementId → String
A unique identifier.
finalinherited
statementType → StatementType
The type of the Statement.
finalinherited

Methods

buildTree(DartBlockProgramTreeNode programTreeNode) → DartBlockProgramTreeNode
override
copy() → BreakStatement
Create a deep copy of the Statement.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(DartBlockArbiter arbiter) → void
Execute the Statement, using the given DartBlockArbiter.
inherited
shuffle() → Statement
Shuffle the contents of the Statement.
inherited
toJson() → Map<String, dynamic>
Encode the Statement object to JSON.
override
toScript({DartBlockTypedLanguage language = DartBlockTypedLanguage.java}) → String
Export the Statement to its equivalent textual representation in a typed language.
override
toString() → String
A string representation of this object.
inherited
trim(int remaining) → (Statement?, int)
Trim the contents of the Statement.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited