ForLoopStatement class

Loops

Inheritance
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ForLoopStatement(Statement? initStatement, DartBlockBooleanExpression condition, Statement? postStatement, List<Statement> bodyStatements, StatementType statementType, String statementId, bool isIsolated)
ForLoopStatement.fromJson(Map<String, dynamic> json)
factory
ForLoopStatement.init(Statement? initStatement, DartBlockBooleanExpression condition, Statement? postStatement, List<Statement> bodyStatements)

Properties

bodyStatements ↔ List<Statement>
getter/setter pair
condition ↔ DartBlockBooleanExpression
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
initStatement ↔ Statement?
getter/setter pair
isIsolated ↔ bool
getter/setter pairinherited
postStatement ↔ Statement?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statementId → String
A unique identifier.
finalinherited
statementType → StatementType
The type of the Statement.
finalinherited

Methods

bodyExecute(DartBlockArbiter arbiter, covariant StatementContextPreExecutionResult? preExecutionResult) → StatementContextBodyExecutionResult?
override
buildTree(DartBlockProgramTreeNode programTreeNode) → DartBlockProgramTreeNode
override
copy() → ForLoopStatement
Create a deep copy of the Statement.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postExecute(DartBlockArbiter arbiter, covariant StatementContextBodyExecutionResult? bodyExecutionResult) → StatementContextPostExecutionResult?
override
preExecute(DartBlockArbiter arbiter) → StatementContextPreExecutionResult?
override
run(DartBlockArbiter arbiter) → StatementContextPostExecutionResult?
Execute the Statement, using the given DartBlockArbiter.
inherited
shuffle() → ForLoopStatement
Shuffle the contents of the Statement.
override
toJson() → Map<String, dynamic>
Encode the Statement object to JSON.
override
toScript({DartBlockTypedLanguage language = DartBlockTypedLanguage.java}) → String
Export the Statement to its equivalent textual representation in a typed language.
override
toString() → String
A string representation of this object.
inherited
trim(int remaining) → (ForLoopStatement?, int)
Trim the contents of the Statement.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited