ButtonGroupItem<T> class

Constructors

ButtonGroupItem({required T value, IconData? icon, String? label, String? tooltip, bool enabled = true})

Properties

enabled ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon ↔ IconData?
getter/setter pair
label ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tooltip ↔ String?
getter/setter pair
value ↔ T
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited