ProviderAwarePopupMenuButton<T> class

A PopupMenuButton that maintains access to Riverpod providers.

This widget wraps the standard PopupMenuButton and ensures that the menu items and their callbacks have access to the parent context's providers.

Inheritance

Constructors

ProviderAwarePopupMenuButton({Key? key, required List<PopupMenuEntry<T>> itemBuilder(BuildContext), T? initialValue, VoidCallback? onOpened, void onSelected(T)?, void onCanceled()?, String? tooltip, double? elevation, Color? shadowColor, Color? surfaceTintColor, EdgeInsetsGeometry? padding = const EdgeInsets.all(8.0), EdgeInsetsGeometry? menuPadding, Widget? child, BorderRadius? borderRadius, double? splashRadius, Widget? icon, double? iconSize, Offset offset = Offset.zero, bool enabled = true, ShapeBorder? shape, Color? color, Color? iconColor, bool? enableFeedback, BoxConstraints? constraints, PopupMenuPosition? position, Clip clipBehavior = Clip.none, bool useRootNavigator = false, AnimationStyle? popUpAnimationStyle, RouteSettings? routeSettings, ButtonStyle? style, bool? requestFocus})
const

Properties

borderRadius → BorderRadius?
final
child → Widget?
final
clipBehavior → Clip
final
color → Color?
final
constraints → BoxConstraints?
final
elevation → double?
final
enabled → bool
final
enableFeedback → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget?
final
iconColor → Color?
final
iconSize → double?
final
initialValue → T?
final
itemBuilder → List<PopupMenuEntry<T>> Function(BuildContext)
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
final
offset → Offset
final
onCanceled → void Function()?
final
onOpened → void Function()?
final
onSelected → void Function(T)?
final
padding → EdgeInsetsGeometry?
final
popUpAnimationStyle → AnimationStyle?
final
position → PopupMenuPosition?
final
requestFocus → bool?
final
routeSettings → RouteSettings?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowColor → Color?
final
shape → ShapeBorder?
final
splashRadius → double?
final
style → ButtonStyle?
final
surfaceTintColor → Color?
final
tooltip → String?
final
useRootNavigator → bool
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited