ToolboxDragTarget class

Widget on which a StatementType can be dropped on to start creating a statement of that type and adding it to that location of the program.

Specifically, the user drags a Draggable from within the StatementStrip of the DartBlockToolbox.

Inheritance

Constructors

ToolboxDragTarget({Key? key, required int nodeKey, required dynamic onSaved(Statement), required bool isEnabled, dynamic onPasteStatement()?, Widget builder(BuildContext, List<StatementType?>, List)?})
const

Properties

builder → Widget Function(BuildContext, List<StatementType?>, List)?
final
hashCode → int
The hash code for this object.
no setterinherited
isEnabled → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
nodeKey → int
final
onPasteStatement → dynamic Function()?
final
onSaved → dynamic Function(Statement)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context, WidgetRef ref) → Widget
Describes the part of the user interface represented by this widget.
createElement() → ConsumerStatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _ConsumerState
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited